/* 
 * File:   SCRDRV.h
 * Author: paul_000
 *
 * Created on January 27, 2017, 2:33 AM
 */

#ifndef SCRDRV_H
#define	SCRDRV_H

#ifdef	__cplusplus
extern "C" {
#endif

#define BYTE        unsigned char
#define STATERR     1
#define STATOK      0
#define MAXCMD      8
#define OUTON       0
#define OUTOFF      1
#define CR          0x0d
#define LF          0x0a
#define TRUE        1
#define FALSE       0

//Bit assignments for PORTA
#define PHASESEL	RA0		//Bit 0, 0-5 VDC from phase adjust pot R29
#define SPARE1		RA1		//Bit 1, Spare
#define SPARE2		RA2		//Bit 2, Spare
#define SPARE3		RA3		//Bit 3, Spare
#define OUTDRV		LATAbits.LATA4		//Bit 4, Output, Open Drain(242 only) (Low Lights yellow D13 and RLY ON)
#define STATLED		LATAbits.LATA5		//Bit 5, Output (Low lights GRN LED, High lights RED LED)

//Bit assignments for PORTB
#define PHREF		RB0		//Input, INT0 (AC Phase reference)
#define INIT		RB1		//Input, INT1 (Initiate)
#define SCR1		LATBbits.LATB2		//Output (High Triggers SCR1 Gate)
#define SCR2		LATBbits.LATB3		//Output (High Triggers SCR2 Gate)
#define SCR2GOFF	PORTBbits.RB4		//Input (Low means voltage on SCR2 G-K)
#define SCR1GOFF	PORTBbits.RB5		//Input (Low means voltage on SCR1 G-K)
#define MOM-        PORTBbits.RB6   //Momentary mode
#define ENA-        PORTBbits.RB7   //Enable

//Bit assignments for PORTC
#define PC0			RC0		
#define PWM1    	RC1		//MOSFET Drive 1 (High A)
#define PWM2		RC2		//MOSFET Drive 2 (Low A)
#define SCK 		RC3		//
#define SDI			RC4		//
#define SDO			RC5		//
#define TXD			RC6		//TXD
#define RXD			RC7		//RXD


#define PWM3CONSET  0b10000000  // <7>EN, <5> OUT, <4> POL (0=HI)
#define	T2CONSET	0b00000010	// <7>N, <6:3>T2OUTPS, <2>T2ON, <0:1> Prescale 00=1 01=4 10=16 11=64
#define     CLKFREQ         14745600              //Clock Frequency
//#define     CLKPER          1000/CLKFREQ    //Clock period (nSec)
#define     PR2_VAL         99              // 199 => 1.25 kHz, 99 => 2.5 kHz
#define PSVAL       16               //Prescaler
#define TM0VAL      19              // reload value for 50 uSec > 1 mSec
#define	OFFSET              1
#define USE_OR_MASKS
#define     PWM_VAL         20              // Percent PWM
    
//extern volatile unsigned long  timer0;
//extern volatile unsigned int   StartCount;
//extern volatile int            maxOnCycles;
//extern volatile int            OnCycles;
//extern volatile BYTE           ADCcount;

void    main (void);
void    interrupt   InterruptHandler (void);
//void    InterruptHandlerLow (void);
void    DelayMsec(int msec);
void    doCommand();
void    id();
void    readCommand();
void    SetupTimer0();
void    SetupADC();
void    SetupUSART();
void    SetupPWM(void);
void    SetupTimer0(void);
void    SetupTimer1(void);
void    SetPWM(int DC);

volatile unsigned long  timer0;
volatile unsigned int   ADCval;
volatile int            maxOnCycles;
volatile int            OnCycles;
volatile unsigned int   Phase;      // Phase angle in degrees, 0-180
volatile unsigned int   StartCount; // Set to phase/3, 1/7200 => 3 degrees, decrement and turn on at zero
volatile BYTE           ADCcount;   // 7200/100 = 72/sec phase pot reading
volatile char           rxChar;
char                    EXTREF, ARMED, STARTED, RUNNING, INITON;
char                    SerialSet = FALSE;
volatile char           Command[MAXCMD+1];


#ifdef	__cplusplus
}
#endif

#endif	/* SCRDRV_H */

